@@ -664,12 +664,12 @@ search_list (GList * list, GtkWindow * parent)
   button = gtk_button_new_from_stock ("gtk-cancel");
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_NO);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
 
   button = gtk_button_new_from_stock ("gtk-ok");
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
 
   e = gtk_entry_new ();
   gtk_box_pack_start (GTK_BOX (box), e, TRUE, TRUE, 0);
@@ -1759,12 +1759,12 @@ editor_triple (struct rdf_t *prev_rdf, gchar * title)
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button,
 				GTK_RESPONSE_CANCEL);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
 
   button = gtk_button_new_from_stock ("gtk-ok");
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
 
   gtk_widget_show_all (dialog);
 
@@ -2255,7 +2255,7 @@ check_list (gchar * str, GtkWindow * parent)
   button = gtk_button_new_with_label (_("Alternative"));
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 1);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
 
   button = gtk_button_new_with_label (_("Sequence"));
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 2);
@@ -2263,7 +2263,7 @@ check_list (gchar * str, GtkWindow * parent)
   button = gtk_button_new_with_label (_("Bag"));
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 3);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
 
   button = gtk_button_new_from_stock ("gtk-no");
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 4);
@@ -2271,7 +2271,7 @@ check_list (gchar * str, GtkWindow * parent)
   button = gtk_button_new_from_stock ("gtk-cancel");
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, 5);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, TRUE);
 
   gtk_widget_show_all (dialog);
 
