@@ -73,7 +73,7 @@ static const gchar *main_path_icon (void);
 /* Questa funzione viene avviata ogni volta che si passa da un documento
  * all'altro usando le label del notebook. Aggiorna undo e redo: */
 static void
-switch_page (GtkWidget * widget, GtkNotebookPage * page, guint page_num)
+switch_page (GtkWidget * widget, gint arg1, gpointer udata)
 {
   struct editor_data_t *data = editor_get_data ();
 
@@ -930,7 +930,6 @@ main (int argc, gchar ** argv, gchar ** e)
   toolbar = gtk_toolbar_new ();
   gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);
   gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
-  gtk_toolbar_set_tooltips (GTK_TOOLBAR (toolbar), TRUE);
 
   button = (GtkWidget *) gtk_tool_button_new_from_stock ("gtk-new");
   gtk_container_add (GTK_CONTAINER (toolbar), button);
@@ -1093,7 +1092,7 @@ main (int argc, gchar ** argv, gchar ** e)
   notebook = gtk_notebook_new ();
   gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
-  g_signal_connect ((gpointer) notebook, "switch_page",
+  g_signal_connect ((gpointer) notebook, "change-current-page",
 		    G_CALLBACK (switch_page), NULL);
 
   statusbar = gtk_statusbar_new ();
