@@ -883,7 +883,7 @@ my_label (struct rdf_t *rdf, const gchar * text, GCallback callback,
 			 GDK_BUTTON_PRESS_MASK |
 			 GDK_KEY_PRESS_MASK |
 			 GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
-  GTK_WIDGET_SET_FLAGS (ebox, GTK_CAN_FOCUS);
+  gtk_widget_set_can_focus(ebox, TRUE);
 
   gtk_widget_show (ebox);
 
@@ -1403,12 +1403,12 @@ change_prefix (GtkWidget * w, struct editor_data_t *data)
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button,
 				GTK_RESPONSE_CANCEL);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
 
   button = gtk_button_new_from_stock ("gtk-ok");
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
 
   gtk_widget_show_all (dialog);
 
@@ -1480,12 +1480,12 @@ change_resources (GtkWidget * w, struct editor_data_t *data)
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button,
 				GTK_RESPONSE_CANCEL);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
 
   button = gtk_button_new_from_stock ("gtk-ok");
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
 
   gtk_widget_show_all (dialog);
 
@@ -1664,12 +1664,12 @@ change_nsresource (GtkWidget * w, struct editor_data_t *data)
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button,
 				GTK_RESPONSE_CANCEL);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
 
   button = gtk_button_new_from_stock ("gtk-ok");
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
 
   gtk_widget_show_all (dialog);
 
