@@ -53,7 +53,7 @@ static void navigator_back (GtkWidget * button, GtkWidget * notebook);
 static void navigator_forward (GtkWidget * button, GtkWidget * notebook);
 static void navigator_quit (GtkWidget * button, GtkWidget * notebook);
 static void navigator_close (GtkWidget * button, GtkWidget * notebook);
-static void navigator_switch_page (GtkWidget * widget, GtkNotebookPage * page,
+static void navigator_switch_page (GtkWidget * widget, gpointer * page,
 				   guint page_num);
 static void navigator_destroy (GtkWidget * notebook);
 static void navigator_free (struct navigator_t *navigator);
@@ -232,8 +232,7 @@ navigator (GList * rdf)
 /* Questa funzione viene attivata quando avviene lo switch tra una page
  * e l'altra del notebook: */
 static void
-navigator_switch_page (GtkWidget * widget, GtkNotebookPage * page,
-		       guint page_num)
+navigator_switch_page (GtkWidget * widget, gpointer * page, guint page_num)
 {
   GtkWidget *back_widget =
     g_object_get_data (G_OBJECT (widget), "back_widget");
@@ -1410,7 +1409,7 @@ navigator_info (GtkWidget * widget, gchar * predicate)
   button = gtk_button_new_from_stock ("gtk-close");
   gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
 
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
 
   frame = gtk_frame_new (NULL);
   gtk_container_set_border_width (GTK_CONTAINER (frame), 3);
