@@ -293,7 +293,6 @@ query (gchar * format)
   toolbar = gtk_toolbar_new ();
   gtk_box_pack_start (GTK_BOX (box), toolbar, FALSE, FALSE, 0);
   gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_BOTH);
-  gtk_toolbar_set_tooltips (GTK_TOOLBAR (toolbar), TRUE);
 
   button = (GtkWidget *) gtk_tool_button_new_from_stock ("gtk-open");
   gtk_container_add (GTK_CONTAINER (toolbar), button);
@@ -428,11 +427,11 @@ query (gchar * format)
 
   button = gtk_button_new_from_stock ("gtk-execute");
   gtk_dialog_add_action_widget (GTK_DIALOG (window), button, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
 
   button = gtk_button_new_from_stock ("gtk-close");
   gtk_dialog_add_action_widget (GTK_DIALOG (window), button, GTK_RESPONSE_NO);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default(button, TRUE);
 
   query_set_change (buffer, FALSE);
   gtk_widget_show_all (window);
